# -*- coding: utf-8 -*-
"""
Created on Wed Mar 28 15:49:46 2018
@author: swerth
"""

import numpy as np
import matplotlib.pyplot as plt
from mpl_toolkits.basemap import Basemap
# requires also PIL package




## Figure 1: blue marble Earth
def figure1():
    plt.figure(figsize=(5, 5))
    m = Basemap(projection='ortho', resolution=None, lat_0=50, lon_0=-100)
    m.bluemarble(scale=0.5);



## Figure 2: etopo USA & Seattle
def figure2():
    fig = plt.figure(figsize=(8, 8))
    m = Basemap(projection='lcc', resolution=None,
                width=8E6, height=8E6, 
                lat_0=45, lon_0=-100,)
    m.etopo(scale=0.5, alpha=0.5)
    # Map (long, lat) to (x, y) for plotting
    x, y = m(-122.3, 47.6)
    plt.plot(x, y, 'ok', markersize=5)
    plt.text(x, y, ' Seattle', fontsize=12);



## Figure 3: Standard Global Projections
def figure3():
    from itertools import chain
    
    # Function to draw map grid
    def draw_map(m, scale=0.2):
        # draw a shaded-relief image
        m.shadedrelief(scale=scale)
        
        # lats and longs are returned as a dictionary
        lats = m.drawparallels(np.linspace(-90, 90, 13))
        lons = m.drawmeridians(np.linspace(-180, 180, 13))
    
        # keys contain the plt.Line2D instances
        lat_lines = chain(*(tup[1][0] for tup in lats.items()))
        lon_lines = chain(*(tup[1][0] for tup in lons.items()))
        all_lines = chain(lat_lines, lon_lines)
        
        # cycle through these lines and set the desired style
        for line in all_lines:
            line.set(linestyle='-', alpha=0.3, color='w')
    
    # global map in Equidistant Cylindrical projection
    fig = plt.figure(figsize=(8, 6), edgecolor='w')
    m = Basemap(projection='cyl', resolution=None,
                llcrnrlat=-90, urcrnrlat=90,
                llcrnrlon=-180, urcrnrlon=180, )
    draw_map(m)
    
    # global map in Mollweide projection
    fig = plt.figure(figsize=(8, 6), edgecolor='w')
    m = Basemap(projection='moll', resolution=None,
                lat_0=0, lon_0=0)
    draw_map(m)
    
    

## Figure 4: Style the Map
def figure4():
    m = Basemap(llcrnrlon=-140.0, llcrnrlat=-20.0,
                urcrnrlon=-60.0, urcrnrlat=60.0,
          	  resolution='c',projection='aea',
            	    lat_1=30.,lat_2=50,lon_0=-97.5,lat_0=38.5)
    m.drawcoastlines()
    m.drawcountries()
    m.fillcontinents(color='coral',lake_color='aqua')
    m.drawmapboundary(fill_color='aqua')

    # draw parallels and meridians.
    m.drawparallels(np.arange(0.,80.,20.))
    m.drawmeridians(np.arange(-180.,181.,20.))

    # draw tissot's indicatrix (~circles) to show distortion
    # function tissot provided by basemap
    ax = plt.gca()
    for y in np.linspace(m.ymax/20,19*m.ymax/20,10):
        for x in np.linspace(m.xmax/20,19*m.xmax/20,12):
            lon, lat = m(x,y,inverse=True)
            poly = m.tissot(lon,lat,1.25,100,
                            facecolor='green',zorder=10,alpha=0.5)
    plt.title("Albers Equal Area Projection")
    plt.show()



## Figure 5: read shapefiles
def figure5():
    map = Basemap(llcrnrlon=-120,llcrnrlat=28.,urcrnrlon=-105.,urcrnrlat=40.,
              resolution='l', projection='tmerc', lat_0 = 0, lon_0 = -110)
    
    map.etopo(scale=1, alpha=0.7)
    map.drawcoastlines()
    map.drawstates()
    map.drawcountries()
    map.readshapefile('ArizonaBorder/Arizona_GADM','ArizonaShape',drawbounds=True,linewidth=1.5,color='r')
    plt.title("Map")
    plt.show()





##############################
### run figure functions:
##############################

figure1()
#figure2()
#figure3()
#figure4()
#figure5()




